@@ -1,7 +1,7 @@
 package Config::IOD::Base;
 
-our $DATE = '2016-03-11'; # DATE
-our $VERSION = '0.24'; # VERSION
+our $DATE = '2016-09-25'; # DATE
+our $VERSION = '0.25'; # VERSION
 
 use 5.010001;
 use strict;
@@ -306,8 +306,8 @@ sub _parse_raw_value {
 sub _decode_json {
     my ($self, $val) = @_;
     state $json = do {
-        require JSON::MaybeXS;
-        JSON::MaybeXS->new->allow_nonref;
+        require JSON;
+        JSON->new->allow_nonref;
     };
     my $res;
     eval { $res = $json->decode($val) };
@@ -431,7 +431,7 @@ Config::IOD::Base - Base class for Config::IOD and Config::IOD::Reader
 
 =head1 VERSION
 
-This document describes version 0.24 of Config::IOD::Base (from Perl distribution Config-IOD-Reader), released on 2016-03-11.
+This document describes version 0.25 of Config::IOD::Base (from Perl distribution Config-IOD-Reader), released on 2016-09-25.
 
 =head1 EXPRESSION
 
@@ -630,7 +630,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Config-IOD
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Config-IOD-Reader>.
+Source repository is at L<https://github.com/sharyanto/perl-Config-IOD-Reader>.
 
 =head1 BUGS
 
